@@ -29,7 +29,7 @@ struct Command LoadCommand =
     {L"", SMALL_PAYLOAD_OPTION, L"", L"", HELP_SPAYLOAD_DETAILS_TEXT, FALSE, ValueEmpty},
     {EXAMINE_OPTION_SHORT, EXAMINE_OPTION, L"", L"", EXAMINE_OPTION_DETAILS_TEXT, FALSE, ValueEmpty},
     {FORCE_OPTION_SHORT, FORCE_OPTION, L"", L"", FORCE_OPTION_DETAILS_TEXT, FALSE, ValueEmpty},
-    { L"", RECOVER_OPTION, L"", HELP_TEXT_FLASH_SPI, RECOVER_OPTION_DETAILS_TEXT, FALSE, ValueOptional }
+    { L"", RECOVER_OPTION, L"", L"", RECOVER_OPTION_DETAILS_TEXT, FALSE, ValueEmpty }
 #ifdef OS_BUILD
     ,{ OUTPUT_OPTION_SHORT, OUTPUT_OPTION, L"", OUTPUT_OPTION_HELP, HELP_OPTIONS_DETAILS_TEXT, FALSE, ValueRequired }
 #endif
@@ -40,7 +40,8 @@ struct Command LoadCommand =
   },
   {{L"", L"", L"", FALSE, ValueOptional}},                            //!< properties
   L"Update the firmware on one or more " PMEM_MODULES_STR L".",                       //!< help
-  Load                                                                //!< run function
+  Load,                                                               //!< run function
+  TRUE                                                                //!< Enable Printer
 };
 
 /**
@@ -92,7 +93,6 @@ Load(
   volatile UINT32 Index2 = 0;
   CHAR16 DimmStr[MAX_DIMM_UID_LENGTH];
   EFI_EVENT ProgressEvent = NULL;
-  BOOLEAN FlashSPI = FALSE;
   CHAR16 *pOptionsValue = NULL;
   BOOLEAN Recovery = FALSE;
   DIMM_INFO *pDimmTargets = NULL;
@@ -116,6 +116,14 @@ Load(
   EFI_HANDLE *pHandles = NULL;
 #endif
 
+  if ((NULL != pCmd) && (NULL != pCmd->pPrintCtx)) {
+    if (pCmd->pPrintCtx->FormatType == XML) {
+      PRINTER_CONFIGURE_BUFFERING(pCmd->pPrintCtx, ON);
+    }
+    else {
+      PRINTER_CONFIGURE_BUFFERING(pCmd->pPrintCtx, OFF);
+    }
+  }
 
   NVDIMM_ENTRY();
   SetDisplayInfo(L"LoadFw", ResultsView, NULL);
@@ -129,22 +137,22 @@ Load(
 
   if (pCmd == NULL) {
     ReturnCode = EFI_INVALID_PARAMETER;
-    Print(FORMAT_STR_NL, CLI_ERR_NO_COMMAND);
+    PrinterSetMsg(NULL, ReturnCode, CLI_ERR_NO_COMMAND);
     goto FinishNoCommandStatus;
   }
 
   // initialize status structure
   ReturnCode = InitializeCommandStatus(&pCommandStatus);
   if (EFI_ERROR(ReturnCode)) {
-    Print(FORMAT_STR_NL, CLI_ERR_INTERNAL_ERROR);
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_INTERNAL_ERROR); // if pCMD->pPrintCtx is NULL then will print to stdout
     NVDIMM_DBG("Failed on InitializeCommandStatus");
     goto FinishNoCommandStatus;
   }
 
   ReturnCode = OpenNvmDimmProtocol(gNvmDimmConfigProtocolGuid, (VOID **)&pNvmDimmConfigProtocol, NULL);
   if (EFI_ERROR(ReturnCode)) {
-    Print(FORMAT_STR_NL, CLI_ERR_OPENING_CONFIG_PROTOCOL);
     ReturnCode = EFI_NOT_FOUND;
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_OPENING_CONFIG_PROTOCOL);
     goto Finish;
   }
 
@@ -152,37 +160,25 @@ Load(
   pFileName = getOptionValue(pCmd, SOURCE_OPTION);
   if (pFileName == NULL) {
     ReturnCode = EFI_INVALID_PARAMETER;
-    Print(FORMAT_STR_NL, CLI_ERR_WRONG_FILE_PATH);
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_WRONG_FILE_PATH);
     goto Finish;
   }
 
   if (containsOption(pCmd, EXAMINE_OPTION) && containsOption(pCmd, EXAMINE_OPTION_SHORT)) {
-    Print(FORMAT_STR_NL, CLI_ERR_OPTIONS_EXAMINE_USED_TOGETHER);
     ReturnCode = EFI_INVALID_PARAMETER;
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_OPTIONS_EXAMINE_USED_TOGETHER);
     goto Finish;
   }
 
   if (containsOption(pCmd, FORCE_OPTION) && containsOption(pCmd, FORCE_OPTION_SHORT)) {
-    Print(FORMAT_STR_NL, CLI_ERR_OPTIONS_FORCE_USED_TOGETHER);
     ReturnCode = EFI_INVALID_PARAMETER;
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_OPTIONS_FORCE_USED_TOGETHER);
     goto Finish;
   }
 
   Recovery = containsOption(pCmd, RECOVER_OPTION);
   Examine = containsOption(pCmd, EXAMINE_OPTION) || containsOption(pCmd, EXAMINE_OPTION_SHORT);
   Force = containsOption(pCmd, FORCE_OPTION) || containsOption(pCmd, FORCE_OPTION_SHORT);
-  //check for the kind of recovery this might be
-  pOptionsValue = getOptionValue(pCmd, RECOVER_OPTION);
-  if (pOptionsValue != NULL) {
-    if (StrICmp(pOptionsValue, RECOVER_OPTION_FLASH_SPI) == 0) {
-      FlashSPI = TRUE;
-    }
-    else if (StrLen(pOptionsValue) > 0) {
-      ReturnCode = EFI_INVALID_PARAMETER;
-      Print(FORMAT_STR_NL, CLI_ERR_INCORRECT_VALUE_OPTION_RECOVER);
-      goto Finish;
-    }
-  }
 
   /*Get the list of functional and non-functional dimms*/
   CHECK_RESULT(GetAllDimmList(pNvmDimmConfigProtocol, pCmd, DIMM_INFO_CATEGORY_SMART_AND_HEALTH,
@@ -190,7 +186,7 @@ Load(
 
   if (DimmCount == 0) {
     ReturnCode = EFI_NOT_STARTED;
-    Print(FORMAT_STR_NL, CLI_INFO_NO_DIMMS);
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_INFO_NO_DIMMS);
     goto Finish;
   }
 
@@ -217,7 +213,7 @@ Load(
     pDimmTargetIds = AllocateZeroPool(sizeof(*pDimmTargetIds) * DimmTargetsNum);
     if (pDimmTargets == NULL || pDimmTargetIds == NULL) {
       ReturnCode = EFI_OUT_OF_RESOURCES;
-      Print(FORMAT_STR_NL, CLI_ERR_OUT_OF_MEMORY);
+      PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_OUT_OF_MEMORY);
       goto Finish;
     }
 
@@ -237,7 +233,7 @@ Load(
     pDimmTargetIds = AllocateZeroPool(sizeof(*pDimmTargetIds) * DimmTargetsNum);
     if (pDimmTargetIds == NULL) {
       ReturnCode = EFI_OUT_OF_RESOURCES;
-      Print(FORMAT_STR_NL, CLI_ERR_OUT_OF_MEMORY);
+      PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_OUT_OF_MEMORY);
       goto Finish;
     }
 
@@ -246,6 +242,11 @@ Load(
     }
   }
 
+  if (NULL == pDimmTargets) {
+    ReturnCode = EFI_NOT_FOUND;
+    CHECK_RETURN_CODE(ReturnCode, Finish);
+  }
+
   /**
     In this case the user could have typed "FS0:\..."
     We are searching for the file on all FS so we need to remove the first chars until we have a "\"
@@ -291,8 +292,8 @@ Load(
 
   pFwImageInfo = AllocateZeroPool(sizeof(*pFwImageInfo));
   if (pFwImageInfo == NULL) {
-    Print(FORMAT_STR_NL, CLI_ERR_OUT_OF_MEMORY);
     ReturnCode = EFI_OUT_OF_RESOURCES;
+    PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, CLI_ERR_OUT_OF_MEMORY);
     goto Finish;
   }
 
@@ -300,7 +301,7 @@ Load(
 
   ResetCmdStatus(pCommandStatus, NVM_ERR_OPERATION_NOT_STARTED);
   if (!Examine) {
-    Print(L"Starting update on %d " PMEM_MODULE_STR L"(s)...\n", DimmTargetsNum);
+    PrinterSetMsg(pCmd->pPrintCtx, EFI_SUCCESS, L"Starting update on %d " PMEM_MODULE_STR L"(s)...", DimmTargetsNum);
     // Create callback that will print progress
     gBS->CreateEvent((EVT_TIMER | EVT_NOTIFY_SIGNAL), PRINT_PRIORITY, PrintProgress, pCommandStatus, &ProgressEvent);
     gBS->SetTimer(ProgressEvent, TimerPeriodic, PROGRESS_EVENT_TIMEOUT);
@@ -310,15 +311,8 @@ Load(
 
     pCommandStatus->GeneralStatus = NVM_SUCCESS; //ensure that only the last error gets reported
 
-    if (pDimmTargets != NULL && pDimmTargets[Index].HealthState == HEALTH_HEALTHY && TRUE == Recovery && TRUE == FlashSPI) {
-      NvmCodes[Index] = NVM_ERR_DIMM_HEALTHY_FW_NOT_RECOVERABLE;
-      ReturnCodes[Index] = MatchCliReturnCode(NvmCodes[Index]);
-      SetObjStatusForDimmInfoWithErase(pCommandStatus, &pDimmTargets[Index], NvmCodes[Index], TRUE);
-      continue;
-    }
-
     //if the FW is already staged and this isn't an examine operation, the outcome is already known
-    if (pDimmTargets != NULL && FALSE == Examine && TRUE == FwHasBeenStaged(pCmd, pNvmDimmConfigProtocol, pDimmTargets[Index].DimmID)) {
+    if (FALSE == Examine && TRUE == FwHasBeenStaged(pCmd, pNvmDimmConfigProtocol, pDimmTargets[Index].DimmID)) {
       pCommandStatus->GeneralStatus = NVM_ERR_FIRMWARE_ALREADY_LOADED;
       NvmCodes[Index] = pCommandStatus->GeneralStatus;
       ReturnCodes[Index] = MatchCliReturnCode(NvmCodes[Index]);
@@ -327,7 +321,7 @@ Load(
     }
 
     ReturnCodes[Index] = pNvmDimmConfigProtocol->UpdateFw(pNvmDimmConfigProtocol, &pDimmTargetIds[Index], 1, pRelativeFileName,
-        (CHAR16 *)pWorkingDirectory, Examine, Force, Recovery, FlashSPI, pFwImageInfo, pCommandStatus);
+        (CHAR16 *)pWorkingDirectory, Examine, Force, Recovery, FALSE, pFwImageInfo, pCommandStatus);
     NvmCodes[Index] = pCommandStatus->GeneralStatus;
 
     if (Examine) {
@@ -365,7 +359,7 @@ Load(
       }
 
       ReturnCodes[Index] = pNvmDimmConfigProtocol->UpdateFw(pNvmDimmConfigProtocol, &pDimmTargetIds[Index], 1, pRelativeFileName,
-        (CHAR16 *)pWorkingDirectory, Examine, TRUE, Recovery, FlashSPI, pFwImageInfo, pCommandStatus);
+        (CHAR16 *)pWorkingDirectory, Examine, TRUE, Recovery, FALSE, pFwImageInfo, pCommandStatus);
       if (EFI_ERROR(ReturnCodes[Index])) {
         continue;
       }
@@ -383,7 +377,7 @@ Load(
       pFwImageInfo->ImageVersion.RevisionNumber.Version != 0 ||
       pFwImageInfo->ImageVersion.SecurityRevisionNumber.Version != 0 ||
       pFwImageInfo->ImageVersion.BuildNumber.Build != 0) {
-      Print(FORMAT_STR L": %02d.%02d.%02d.%04d\n",
+      PrinterSetMsg(pCmd->pPrintCtx, ReturnCode, FORMAT_STR L": %02d.%02d.%02d.%04d",
         pFileName,
         pFwImageInfo->ImageVersion.ProductNumber.Version,
         pFwImageInfo->ImageVersion.RevisionNumber.Version,
@@ -392,8 +386,7 @@ Load(
     }
   } else {
     gBS->CloseEvent(ProgressEvent);
-    Print(L"\n");
-    if (!FlashSPI && StagedFwUpdates > 0) {
+    if (StagedFwUpdates > 0) {
       /*
       At this point, all indications are that the FW is on the way to being staged.
       Loop until they all report a staged version
@@ -428,10 +421,14 @@ Load(
   }
 
 Finish:
-  PRINTER_PROMPT_COMMAND_STATUS(pCmd->pPrintCtx, ReturnCode, CLI_INFO_LOAD_FW, CLI_INFO_ON, pCommandStatus);
+  PRINTER_SET_COMMAND_STATUS(pCmd->pPrintCtx, ReturnCode, CLI_INFO_LOAD_FW, CLI_INFO_ON, pCommandStatus);
   FreeCommandStatus(&pCommandStatus);
 
 FinishNoCommandStatus:
+  // if no PrintCtx then nothing can be buffered so no need to process it
+  if ((NULL != pCmd)) {
+    PRINTER_PROCESS_SET_BUFFER(pCmd->pPrintCtx);
+  }
   FREE_POOL_SAFE(pFileName);
   FREE_POOL_SAFE(pFwImageInfo);
   FREE_POOL_SAFE(pDimmIds);
