@@ -14,6 +14,7 @@
 #include <Utility.h>
 #include <NvmInterface.h>
 #include "Common.h"
+#include "NvmDimmCli.h"
 
 CONST CHAR16 *pPoisonMemoryTypeStr[POISON_MEMORY_TYPE_COUNT] = {
   L"MemoryMode",
@@ -156,6 +157,7 @@ SetDimm(
   CHAR16 *pFatalMediaError = NULL;
   CHAR16 *pDirtyShutDown = NULL;
   CHAR16 *pClearErrorInj = NULL;
+  CHAR16 *pClearErrInjMessage = NULL;
   UINT16 ErrInjectType = ERROR_INJ_TYPE_INVALID;
   UINT64 TemperatureValue = 0;
   UINT64 PoisonAddressValue = 0;
@@ -189,7 +191,7 @@ SetDimm(
   }
 
   // Populate the list of DIMM_INFO structures with relevant information
-  ReturnCode = GetDimmList(pNvmDimmConfigProtocol, pCmd, DIMM_INFO_CATEGORY_NONE, &pDimms, &DimmCount);
+  ReturnCode = GetDimmList(pNvmDimmConfigProtocol, pCmd, DIMM_INFO_CATEGORY_SECURITY, &pDimms, &DimmCount);
   if (EFI_ERROR(ReturnCode)) {
     if(ReturnCode == EFI_NOT_FOUND) {
         PRINTER_SET_MSG(pCmd->pPrintCtx, ReturnCode, CLI_INFO_NO_FUNCTIONAL_DIMMS);
@@ -218,11 +220,6 @@ SetDimm(
       PRINTER_SET_MSG(pPrinterCtx, ReturnCode, CLI_ERR_UNMANAGEABLE_DIMM);
       goto Finish;
     }
-    if (!AllDimmsInListInSupportedConfig(pDimms, DimmCount, pDimmIds, DimmIdsCount)) {
-      ReturnCode = EFI_INVALID_PARAMETER;
-      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, CLI_ERR_POPULATION_VIOLATION);
-      goto Finish;
-    }
   }
 
   /** If no dimm IDs are specified get IDs from all dimms **/
@@ -380,21 +377,11 @@ SetDimm(
   GetPropertyValue(pCmd, CONFIRMPASSPHRASE_PROPERTY, &pConfirmPassphraseStatic);
 
   if (MasterOptionSpecified) {
-    ReturnCode = pNvmDimmConfigProtocol->GetDimms(pNvmDimmConfigProtocol, DimmCount, DIMM_INFO_CATEGORY_SECURITY, pDimms);
-    if (EFI_ERROR(ReturnCode)) {
-      ReturnCode = EFI_ABORTED;
-      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, CLI_ERR_INTERNAL_ERROR);
-      NVDIMM_WARN("Failed to retrieve the DIMM inventory found in NFIT");
+    if (!AllDimmsInListHaveMasterPassphraseEnabled(pDimms, DimmCount, pDimmIds, DimmIdsCount)) {
+      ReturnCode = EFI_INVALID_PARAMETER;
+      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, CLI_ERR_MASTER_PASSPHRASE_NOT_ENABLED);
       goto Finish;
     }
-
-    for (Index = 0; Index < DimmCount; Index++) {
-      if (pDimms[Index].MasterPassphraseEnabled != TRUE) {
-        ReturnCode = EFI_INVALID_PARAMETER;
-        PRINTER_SET_MSG(pPrinterCtx, ReturnCode, CLI_ERR_MASTER_PASSPHRASE_NOT_ENABLED);
-        goto Finish;
-      }
-    }
   }
 
   pLoadFilePath = AllocateZeroPool(OPTION_VALUE_LEN * sizeof(*pLoadFilePath));
@@ -848,11 +835,15 @@ SetDimm(
     if (EFI_ERROR(ReturnCode)) {
       goto FinishCommandStatusSet;
     }
+    pClearErrInjMessage = GetSingleNvmStatusCodeMessage(gNvmDimmCliHiiHandle, NVM_WARN_CLEARED_ERR_INJ_REQUIRES_REBOOT);
   }
 
 FinishCommandStatusSet:
   ReturnCode = MatchCliReturnCode(pCommandStatus->GeneralStatus);
   PRINTER_SET_COMMAND_STATUS(pPrinterCtx, ReturnCode, pCommandStatusMessage, pCommandStatusPreposition, pCommandStatus);
+  if (NVM_WARN_CLEARED_ERR_INJ_REQUIRES_REBOOT == pCommandStatus->GeneralStatus) {
+    PRINTER_SET_MSG(pPrinterCtx, ReturnCode, FORMAT_STR, pClearErrInjMessage);
+  }
 Finish:
   PRINTER_PROCESS_SET_BUFFER(pPrinterCtx);
   FreeCommandStatus(&pCommandStatus);
@@ -875,6 +866,7 @@ Finish:
   FREE_POOL_SAFE(pCommandStatusPreposition);
   FREE_POOL_SAFE(pAvgPowerReportingTimeConstantMult);
   FREE_POOL_SAFE(pAvgPowerReportingTimeConstant);
+  FREE_POOL_SAFE(pClearErrInjMessage);
   NVDIMM_EXIT_I64(ReturnCode);
   return ReturnCode;
 }
