@@ -40,7 +40,7 @@ struct Command ShowErrorCommandSyntax =
     {LEVEL_PROPERTY, L"", HELP_TEXT_ERROR_LOG_LEVEL_PROPERTY, FALSE, ValueRequired},
     {COUNT_PROPERTY, L"", HELP_TEXT_ERROR_LOG_COUNT_PROPERTY, FALSE, ValueRequired}
   },                                                                  //!< properties
-  L"Show error log for one or more DCPMMs.",                          //!< help
+  L"Show error log for one or more " PMEM_MODULES_STR L".",                          //!< help
   ShowErrorCommand,                                                   //!< run function
   TRUE
 };
@@ -453,11 +453,11 @@ ShowErrorCommand(
       if (pCommandStatus->GeneralStatus != NVM_SUCCESS) {
         ReturnCode = MatchCliReturnCode(pCommandStatus->GeneralStatus);
       }
-      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"Failed to get error logs from DIMM " FORMAT_STR L"\n", DimmStr);
+      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"Failed to get error logs from " PMEM_MODULE_STR L" " FORMAT_STR L"\n", DimmStr);
       continue;
     }
     if (ReturnedCount == 0) {
-      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"No errors found on DIMM " FORMAT_STR L"\n", DimmStr);
+      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"No errors found on " PMEM_MODULE_STR L" " FORMAT_STR L"\n", DimmStr);
     }
     else {
       PRINTER_BUILD_KEY_PATH(pPath, DS_DIMM_INDEX_PATH, Index);
@@ -514,6 +514,7 @@ ShowErrorCommand(
         else {
 
           pMediaErrorInfo = (MEDIA_ERROR_LOG_INFO *)ErrorsArray[Index2].OutputData;
+          ExcludeInvalidFields = FALSE;
 
           // Error Type
           switch (pMediaErrorInfo->ErrorType) {
