@@ -106,7 +106,7 @@ struct Command ShowGoalCommand =
     {SOCKET_TARGET, L"", HELP_TEXT_SOCKET_IDS, FALSE, ValueOptional}
   },
   {{L"", L"", L"", FALSE, ValueOptional}},                              //!< properties
-  L"Show a pending memory allocation goal on one or more DCPMMs to be applied on reboot.",            //!< help
+  L"Show a pending memory allocation goal on one or more " PMEM_MODULES_STR L" to be applied on reboot.",            //!< help
   ShowGoal,
   TRUE,                                                                 //!< enable print control support
 };
@@ -349,7 +349,7 @@ ShowGoal(
   UINT16 *pDimmIds = NULL;
   UINT16 *pSocketIds = NULL;
   UINT16 UnitsOption = DISPLAY_SIZE_UNIT_UNKNOWN;
-  UINT16 UnitsToDisplay = FixedPcdGet32(PcdDcpmmCliDefaultCapacityUnit);
+  UINT16 UnitsToDisplay = FixedPcdGet16(PcdDcpmmCliDefaultCapacityUnit);
   UINT32 DimmIdsCount = 0;
   UINT32 SocketIdsCount = 0;
   UINT32 RegionConfigsCount = 0;
