@@ -573,7 +573,7 @@ EFI_STATUS
   @param[in] Examine flag enables image verification only
   @param[in] Force flag suppresses warning message in case of attempted downgrade
   @param[in] Recovery **Deprecated** Run the update on non-functional PMem modules only
-  @param[in] FlashSpi Run a full PMem module SPI recovery
+  @param[in] Reserved Set to FALSE
 
   @param[out] pFwImageInfo is a pointer to a structure containing FW image information
     need to be provided if examine flag is set
@@ -596,7 +596,7 @@ EFI_STATUS
   IN     BOOLEAN Examine,
   IN     BOOLEAN Force,
   IN     BOOLEAN Recovery,
-  IN     BOOLEAN FlashSPI,
+  IN     BOOLEAN Reserved,
      OUT NVM_FW_IMAGE_INFO *pFwImageInfo OPTIONAL,
      OUT COMMAND_STATUS *pCommandStatus
 );
