@@ -598,7 +598,9 @@ typedef struct _MEMORY_RESOURCES_INFO {
   UINT64 DDRCacheCapacity;          //!< Sum of the DDR capacity used for caching
   UINT64 DDRVolatileCapacity;       //!< Sum of the DDR capacity used as volatile memory
   UINT64 DDRInaccessibleCapacity;   //!< Sum of the DDR capacity that is inaccessible
-  UINT64 Reserved[6];
+  BOOLEAN PcdInvalid;               //!< Boolean flag to indicate one or more PMem modules have missing or corrupt PCD
+  UINT8 Reserved1[5];
+  UINT64 Reserved2[5];
 } MEMORY_RESOURCES_INFO;
 
 typedef struct _DIMM_PERFORMANCE_DATA {
@@ -849,6 +851,11 @@ typedef struct _DEBUG_LOG_INFO {
 #define DIMM_BOOT_STATUS_DDRT_NOT_READY       BIT5
 #define DIMM_BOOT_STATUS_MAILBOX_NOT_READY    BIT6
 #define DIMM_BOOT_STATUS_REBOOT_REQUIRED      BIT7
+// Meta-flags
+#define DIMM_MEDIA_NOT_ACCESSIBLE(BootStatusBitmask)       \
+  ((BootStatusBitmask & DIMM_BOOT_STATUS_MEDIA_NOT_READY) ||  \
+  (BootStatusBitmask & DIMM_BOOT_STATUS_MEDIA_ERROR) ||       \
+  (BootStatusBitmask & DIMM_BOOT_STATUS_MEDIA_DISABLED))      \
 
 /**
   System-wide ARS Status Bitmask
@@ -995,10 +1002,16 @@ typedef struct _DEBUG_LOG_INFO {
 #define AVG_PWR_REPORTING_TIME_CONSTANT_MULT_DEFAULT               0
 #define HII_AVG_PWR_REPORTING_TIME_CONSTANT_MULT_MAX_STR_LEN       3
 
-#define AVG_PWR_REPORTING_TIME_CONSTANT_MAX                        12000
+
+// These values are now hard-coded into error strings in NvmDimmHii.uni for code simplicity.
+// Update STR_DCPMM_CONFIGURE_DATA_POLICY_VALUE_TOO_BIG_AVG_PWR_REPORTING_TIME_CONSTANT and friends
+// with any updated values. Main reason for going this way as opposed to appending onto the end
+// of an error string is that I wanted a thousands comma for readability: "12000" --> "12,000"
+#define AVG_PWR_REPORTING_TIME_CONSTANT_DEFAULT                    1000
 #define AVG_PWR_REPORTING_TIME_CONSTANT_MIN                        100
 #define AVG_PWR_REPORTING_TIME_CONSTANT_STEP                       100
-#define HII_AVG_PWR_REPORTING_TIME_CONSTANT_MAX_STR_LEN            6
+#define AVG_PWR_REPORTING_TIME_CONSTANT_MAX                        12000
+#define AVG_PWR_REPORTING_TIME_CONSTANT_MAX_STR_LEN                8 // Includes potential values of "Mixed" and "Unknown"
 
 /**
   Namespace security capabilities.
