@@ -1046,7 +1046,8 @@ static VOID PrintXmlEndSuccessTag(PRINT_CONTEXT *PrintCtx, EFI_STATUS CmdExitCod
 /*
 * Helper that creates a message out of a COMMAND_STATUS object.
 */
-static EFI_STATUS CreateCmdStatusMsg(CHAR16 **ppMsg, CHAR16 *pStatusMessage, CHAR16 *pStatusPreposition, COMMAND_STATUS *pCommandStatus) {
+static EFI_STATUS CreateCmdStatusMsg(CHAR16 **ppMsg, CHAR16 *pStatusMessage, CHAR16 *pStatusPreposition,
+    BOOLEAN DoNotPrintGeneralStatusSuccessCode, COMMAND_STATUS *pCommandStatus) {
   EFI_STATUS ReturnCode = EFI_INVALID_PARAMETER;
   UINT8 DimmIdentifier = 0;
   BOOLEAN ObjectIdNumberPreferred = FALSE;
@@ -1059,7 +1060,7 @@ static EFI_STATUS CreateCmdStatusMsg(CHAR16 **ppMsg, CHAR16 *pStatusMessage, CHA
   ObjectIdNumberPreferred = DimmIdentifier == DISPLAY_DIMM_ID_HANDLE;
 
   ReturnCode = CreateCommandStatusString(gNvmDimmCliHiiHandle, pStatusMessage, pStatusPreposition, pCommandStatus,
-    ObjectIdNumberPreferred, ppMsg);
+    ObjectIdNumberPreferred, DoNotPrintGeneralStatusSuccessCode, ppMsg);
 
 Finish:
   return ReturnCode;
@@ -1085,6 +1086,8 @@ EFI_STATUS PrinterCreateCtx(
   InitializeListHead(&((*ppPrintCtx)->BufferedObjectList));
   InitializeListHead(&((*ppPrintCtx)->DataSetLookup));
   InitializeListHead(&((*ppPrintCtx)->DataSetRootLookup));
+
+  (*ppPrintCtx)->DoNotPrintGeneralStatusSuccessCode = FALSE;
 Finish:
   return ReturnCode;
 }
@@ -1306,7 +1309,7 @@ Finish:
 * Handle commandstatus objects
 */
 EFI_STATUS PrinterSetCommandStatus(
-  IN     PRINT_CONTEXT *pPrintCtx,
+  IN     PRINT_CONTEXT *pPrintCtx, OPTIONAL
   IN     EFI_STATUS Status,
   IN     CHAR16 *pStatusMessage,
   IN     CHAR16 *pStatusPreposition,
@@ -1315,13 +1318,19 @@ EFI_STATUS PrinterSetCommandStatus(
 {
   EFI_STATUS ReturnCode = EFI_INVALID_PARAMETER;
   CHAR16 *FullMsg = NULL;
+  BOOLEAN DoNotPrintGeneralStatusSuccessCode = FALSE;
 
-  if (NULL == pCommandStatus && NULL == pPrintCtx) {
+  if (NULL == pCommandStatus) {
     NVDIMM_ERR("Invalid input parameter\n");
     goto Finish;
   }
 
-  if (EFI_SUCCESS != (ReturnCode = CreateCmdStatusMsg(&FullMsg, pStatusMessage, pStatusPreposition, pCommandStatus))) {
+  if (pPrintCtx != NULL) {
+    DoNotPrintGeneralStatusSuccessCode = pPrintCtx->DoNotPrintGeneralStatusSuccessCode;
+  }
+
+  if (EFI_SUCCESS != (ReturnCode = CreateCmdStatusMsg(&FullMsg, pStatusMessage, pStatusPreposition,
+      DoNotPrintGeneralStatusSuccessCode, pCommandStatus))) {
     goto Finish;
   }
 
@@ -1355,7 +1364,7 @@ static PRINT_MODE PrintMode(
 }
 
 /*
-* Process all objects int the "set buffer"
+* Process all objects in the "set buffer"
 */
 EFI_STATUS PrinterProcessSetBuffer(
   IN     PRINT_CONTEXT *pPrintCtx
@@ -1371,6 +1380,7 @@ EFI_STATUS PrinterProcessSetBuffer(
   BOOLEAN startXmlErrorPrinted = FALSE;
 
   if (NULL == pPrintCtx) {
+    NVDIMM_ERR("Invalid input parameter\n");
     return EFI_INVALID_PARAMETER;
   }
 
@@ -1431,7 +1441,8 @@ EFI_STATUS PrinterProcessSetBuffer(
     }
     else if (BUFF_COMMAND_STATUS_TYPE == BufferedObject->Type) {
       BUFFERED_COMMAND_STATUS *pTempCs = (BUFFERED_COMMAND_STATUS *)BufferedObject->Obj;
-      CreateCmdStatusMsg(&FullMsg, pTempCs->pStatusMessage, pTempCs->pStatusPreposition, pTempCs->pCommandStatus);
+      CreateCmdStatusMsg(&FullMsg, pTempCs->pStatusMessage, pTempCs->pStatusPreposition,
+          pPrintCtx->DoNotPrintGeneralStatusSuccessCode, pTempCs->pCommandStatus);
       if (PRINT_XML != PrinterMode) {
         PrintTextWithNewLine(FullMsg);
       }
