@@ -127,6 +127,7 @@ typedef struct _PRINT_CONTEXT {
   UINTN BufferedDataSetCnt;
   LIST_ENTRY DataSetLookup;
   LIST_ENTRY DataSetRootLookup;
+  BOOLEAN DoNotPrintGeneralStatusSuccessCode;
 }PRINT_CONTEXT;
 
 typedef struct _LIST_LEVEL_ATTRIB {
@@ -251,7 +252,7 @@ do { \
 do { \
   EFI_STATUS rc; \
   PRINTER_CONFIGURE_BUFFERING(ctx, OFF); \
-  if( EFI_SUCCESS != (rc = PrinterSetCommandStatus(ctx, efi_status, status_msg, status_preposition, command_status))) { \
+  if(EFI_SUCCESS != (rc = PrinterSetCommandStatus(ctx, efi_status, status_msg, status_preposition, command_status))) { \
     NVDIMM_CRIT("Failed to prompt a command status object! (" FORMAT_EFI_STATUS ")", rc); \
   } \
 } while(0)
@@ -264,7 +265,7 @@ do { \
 do { \
   EFI_STATUS rc; \
   PRINTER_CONFIGURE_BUFFERING(ctx, ON); \
-  if( EFI_SUCCESS != (rc = PrinterSetCommandStatus(ctx, efi_status, status_msg, status_preposition, command_status))) { \
+  if(EFI_SUCCESS != (rc = PrinterSetCommandStatus(ctx, efi_status, status_msg, status_preposition, command_status))) { \
     NVDIMM_CRIT("Failed to buffer a command status object! (" FORMAT_EFI_STATUS ")", rc); \
   } \
 } while(0)
@@ -273,7 +274,7 @@ do { \
 #define PRINTER_PROCESS_SET_BUFFER(ctx) \
 do { \
   EFI_STATUS rc; \
-  if( EFI_SUCCESS != (rc = PrinterProcessSetBuffer(ctx))) { \
+  if(EFI_SUCCESS != (rc = PrinterProcessSetBuffer(ctx))) { \
     NVDIMM_CRIT("Failed to process printer objects! (" FORMAT_EFI_STATUS ")", rc); \
   } \
 } while (0)
@@ -490,7 +491,7 @@ EFI_STATUS PrinterSetData(
 * Handle commandstatus objects
 */
 EFI_STATUS PrinterSetCommandStatus(
-  IN     PRINT_CONTEXT *pPrintCtx,
+  IN     PRINT_CONTEXT *pPrintCtx, OPTIONAL
   IN     EFI_STATUS Status,
   IN     CHAR16 *pStatusMessage,
   IN     CHAR16 *pStatusPreposition,
