@@ -382,17 +382,29 @@ if (NVM_SUCCESS != os_check_admin_permissions()) { \
   do {                                                        \
     ReturnCode = Call;                                        \
     if (EFI_ERROR(ReturnCode)) {                              \
-      NVDIMM_ERR("Failure on function: %d", ReturnCode);      \
+      NVDIMM_ERR("Failure with %s. RC: %d", #Call, ReturnCode); \
       goto Label;                                             \
     }                                                         \
   } while (0)
 
+// Return if failure
+#define CHECK_RESULT_SAVE_RETURNCODE(Call, Label)             \
+  do {                                                        \
+    TempReturnCode = ReturnCode;                              \
+    ReturnCode = Call;                                        \
+    if (EFI_ERROR(ReturnCode)) {                              \
+      NVDIMM_ERR("Failure with %s. RC: %d", #Call, ReturnCode); \
+      goto Label;                                             \
+    }                                                         \
+    ReturnCode = TempReturnCode;                              \
+  } while (0)
+
 // Return if failure
 #define CHECK_RESULT_SET_NVM_STATUS(Call, pNvmStatus, NvmStatusCode, Label) \
   do {                                                                      \
     ReturnCode = Call;                                                      \
     if (EFI_ERROR(ReturnCode)) {                                            \
-      NVDIMM_ERR("Failure on function: %d", ReturnCode);                    \
+      NVDIMM_ERR("Failure with %s. RC: %d", #Call, ReturnCode);             \
       *pNvmStatus = NvmStatusCode;                                          \
       goto Label;                                                           \
     }                                                                       \
@@ -408,19 +420,20 @@ if (NVM_SUCCESS != os_check_admin_permissions()) { \
   } while (0)
 
 // Ignore error code, but print it out
-#define CHECK_RESULT_CONTINUE(Call)                           \
-  do {                                                        \
-    ReturnCode = Call;                                        \
-    if (EFI_ERROR(ReturnCode)) {                              \
-      NVDIMM_ERR("Failure on function: %d", ReturnCode);      \
-    }                                                         \
+#define CHECK_RESULT_CONTINUE(Call)                                 \
+  do {                                                              \
+    ReturnCode = Call;                                              \
+    if (EFI_ERROR(ReturnCode)) {                                    \
+      NVDIMM_WARN("Ignoring failure with %s. RC: %d", #Call, ReturnCode); \
+      ReturnCode = EFI_SUCCESS;                                     \
+    }                                                               \
   } while (0)
 
 #define CHECK_RESULT_MALLOC(Pointer, Call, Label)             \
   do {                                                        \
     Pointer = Call;                                           \
     if (Pointer == NULL) {                                    \
-      NVDIMM_ERR("Failed to allocate memory");                \
+      NVDIMM_ERR("Failed to allocate memory to %s", #Pointer); \
       ReturnCode = EFI_OUT_OF_RESOURCES;                      \
       goto Label;                                             \
     }                                                         \
@@ -430,7 +443,7 @@ if (NVM_SUCCESS != os_check_admin_permissions()) { \
   do {                                                                    \
     ReturnCode = Call;                                                    \
     if (EFI_ERROR(ReturnCode)) {                                          \
-      NVDIMM_ERR("Error in file operation");                              \
+      NVDIMM_ERR("Error in file operation %s", #Call);                    \
       ResetCmdStatus(pCommandStatus, NVM_ERR_DUMP_FILE_OPERATION_FAILED); \
       goto Label;                                                         \
     }                                                                     \
@@ -440,7 +453,16 @@ if (NVM_SUCCESS != os_check_admin_permissions()) { \
 #define CHECK_NOT_TRUE(Call, Label)                                        \
   do {                                                                    \
     if (TRUE != Call) {                                                   \
-      NVDIMM_ERR("Statement is not true");                                \
+      NVDIMM_ERR("Statement %s is not true", #Call);                      \
+      goto Label;                                                         \
+    }                                                                     \
+  } while (0)
+
+#define CHECK_NULL_ARG(Argument, Label)                                   \
+  do {                                                                    \
+    if (NULL == (VOID *)Argument) {                                       \
+      NVDIMM_ERR("Argument %s is NULL. Exiting", #Argument);              \
+      ReturnCode = EFI_INVALID_PARAMETER;                                 \
       goto Label;                                                         \
     }                                                                     \
   } while (0)
@@ -541,29 +563,6 @@ GetEnvVariable(
   IN     CHAR16 *pVarName
   );
 
-/**
-  Examines the system topology for the system DDR capacity and compares
-  it to the 2LM capacity to check for ratio violations
-
-  @param[IN]  pNvmDimmConfigProtocol the protocol
-  @param[IN]  pRegionConfigsInfo a pointer to the region list to examine
-  @param[IN]  RegionConfigsCount the number of REGION_GOAL_PER_DIMM_INFO elements in the list
-  @param[OUT] pIsAboveLimit the 2LM vs DDR value is above the upper recommended limit
-  @param[OUT] pIsBelowLimit the 2LM vs DDR value is below the lower recommended limit
-
-  @retval EFI_SUCCESS Success
-  @retval EFI_INVALID_PARAMETER input parameter null
-  @retval EFI_DEVICE_ERROR failed to get the system topology
-**/
-EFI_STATUS
-CheckNmFmLimits(
-  IN    EFI_DCPMM_CONFIG2_PROTOCOL *pNvmDimmConfigProtocol,
-  IN    REGION_GOAL_PER_DIMM_INFO *pRegionConfigsInfo,
-  IN    UINT32  RegionConfigsCount,
-  OUT   BOOLEAN *pIsAboveLimit,
-  OUT   BOOLEAN *pIsBelowLimit
-);
-
 /**
   Checks if the Config Protocol version is right.
 
@@ -1978,6 +1977,23 @@ MatchCliReturnCode (
   IN     NVM_STATUS Status
  );
 
+ /**
+  Guess an appropriate NVM_STATUS code from EFI_STATUS. For use when
+  pCommandStatus is not an argument to a lower level function.
+
+  Used currently to get specific errors relevant to the user out to
+  the CLI but not many (especially lower-level) functions have
+  pCommandStatus. Also the CLI printer doesn't use ReturnCode,
+  only pCommandStatus.
+
+  @param[in] ReturnCode - EFI_STATUS returned from function call
+  @retval - Appropriate guess at the NVM_STATUS code
+**/
+NVM_STATUS
+GuessNvmStatusFromReturnCode(
+  IN EFI_STATUS ReturnCode
+);
+
 #ifndef OS_BUILD
 /**
   Find serial attributes from SerialProtocol and set on
