@@ -486,6 +486,7 @@ ADNamespaceMinAndMaxAvailableSizeOnIS(
   Retrieve goal configurations by using Platform Config Data
 
   @param[in, out] pDimmList Head of the list of all NVM DIMMs in the system
+  @param[in] Restore corrupt pcd
 
   @retval EFI_SUCCESS
   @retval EFI_INVALID_PARAMETER one or more parameters are NULL
@@ -1040,4 +1041,62 @@ CheckForExistingGoalConfigPerSocket(
   IN    DIMM *pDimms[MAX_DIMMS],
   IN    UINT32 *pDimmsNum
   );
+
+/**
+  Examines the system topology for the system DDR capacity and compares
+  it to the 2LM capacity to check for ratio violations
+
+  @param[in] SocketId Socket Id, value 0xFFFF indicates include all socket values
+  @param[in] pDimmsSym Array of Dimms for symmetrical region config
+  @param[in] DimmsSymNum Number of items in DimmsSym
+  @param[out] pCommandStatus Pointer to command status structure
+
+  @retval EFI_SUCCESS Success
+  @retval EFI_INVALID_PARAMETER input parameter null
+**/
+EFI_STATUS
+CheckNmFmLimits(
+  IN     UINT16 SocketId,
+  IN     REGION_GOAL_DIMM *pDimmsSym,
+  IN     UINT32  DimmsSymNum,
+     OUT COMMAND_STATUS *pCommandStatus
+  );
+
+/**
+  Checks if all DIMMs in the list are in configured state
+
+  @param[IN] pDimmList Head of the Dimm list
+  @param[IN] pDimmsUnConfigured Boolean flag to indicate if any PMem module is unconfigured
+  @param[OUT] pCommandStatus Pointer to command status structure
+
+  @retval EFI_SUCCESS Success
+  @retval EFI_INVALID_PARAMETER if input parameter null
+**/
+EFI_STATUS
+CheckIfAllDimmsConfigured(
+  IN     LIST_ENTRY *pDimmList,
+     OUT BOOLEAN *pDimmsUnConfigured,
+     OUT COMMAND_STATUS *pCommandStatus OPTIONAL
+  );
+
+/**
+  Calculate total far memory on PMem modules for existing goal configs
+
+  @param[in] SocketId Socket Id, value 0xFFFF indicates include all socket values
+  @param[in] pDimmsSym Array of Dimms for symmetrical region config
+  @param[in] DimmsSymNum Number of items in DimmsSym
+  @param[out] pTotalFarMemorySize Pointer to total far memory capacity
+  @param[out] pCommandStatus Pointer to command status structure
+
+  @retval EFI_SUCCESS Success
+  @retval EFI_INVALID_PARAMETER if input parameter null
+**/
+EFI_STATUS
+CalculateFarMemorySizeForNewGoalConfigs(
+  IN     UINT16 SocketId,
+  IN     REGION_GOAL_DIMM *pDimmsSym,
+  IN     UINT32  DimmsSymNum,
+     OUT UINT64 *pTotalFarMemorySize,
+     OUT COMMAND_STATUS *pCommandStatus
+  );
 #endif
