@@ -254,6 +254,11 @@ ReenumerateNamespacesAndISs(
 #ifndef OS_BUILD
   NVDIMM_ENTRY();
 
+  // TODO: Look into using ReinstallProtocolInterface() for the DoDriverCleanup
+  // flow instead of manually for a simpler implementation.
+  // Documentation is in the UEFI EDK2 Driver Writer's Guide.
+  // Include runtime PCD corruption detection and device state
+  // (i.e. goes down) in test cases.
   if (DoDriverCleanup == TRUE) {
     ReturnCode = CleanNamespacesAndISs();
     if (EFI_ERROR(ReturnCode)) {
@@ -261,13 +266,19 @@ ReenumerateNamespacesAndISs(
     }
   }
 
-  /** Initialize Interleave Sets **/
+  // Initialize Interleave Sets using PCD
   ReturnCode = InitializeInterleaveSets(FALSE);
   if (EFI_ERROR(ReturnCode)) {
     NVDIMM_WARN("Failed to retrieve the REGION/IS list from PCD, error = " FORMAT_EFI_STATUS ".", ReturnCode);
     goto Finish;
   }
 
+  // Initialize Interleave Sets using NFIT table
+  ReturnCode = InitializeInterleaveSets(TRUE);
+  if (EFI_ERROR(ReturnCode)) {
+    NVDIMM_WARN("Failed to retrieve the REGION/IS list from NFIT, error = " FORMAT_EFI_STATUS ".", ReturnCode);
+  }
+
   /** Initialize Namespaces (read LSA, enumerate every namespace) **/
   ReturnCode = InitializeNamespaces();
   if (EFI_ERROR(ReturnCode)) {
@@ -1157,10 +1168,11 @@ InitializeDimms()
 #endif
    if (PcdUsage) {
     /**
-      Initialize Interleave Sets
       We try to initialize all Regions, but if something goes wrong with a specific Region, then we just don't
       create the Region or add a proper error state to it. So even then we continue the driver initialization.
     **/
+
+    // Initialize Interleave Sets using PCD
     ReturnCode = InitializeInterleaveSets(FALSE);
     if (EFI_ERROR(ReturnCode)) {
       NVDIMM_WARN("Failed to retrieve the REGION/IS list from PCD, error = " FORMAT_EFI_STATUS ".", ReturnCode);
@@ -1356,6 +1368,7 @@ NvmDimmDriverDriverBindingStart(
    ReturnCode = initAcpiTables();
    if (EFI_ERROR(ReturnCode)) {
       NVDIMM_WARN("Failed to initialize the ACPI tables, error = " FORMAT_EFI_STATUS ".", ReturnCode);
+      goto Finish;
    }
 
    /**
@@ -1554,6 +1567,7 @@ NvmDimmDriverDriverBindingStart(
    ReturnCode = initAcpiTables();
    if (EFI_ERROR(ReturnCode)) {
       NVDIMM_WARN("Failed to initialize the ACPI tables, error = " FORMAT_EFI_STATUS ".", ReturnCode);
+      goto Finish;
    }
 
    /**
@@ -2015,14 +2029,22 @@ ResolveDeviceType(
   *pResultDevice = Dimm;
   ReturnCode = HandleToPID(ChildHandle, NULL, &DimmPid);
   if (EFI_ERROR(ReturnCode)) {
-    // We couldn't find the DIMM, apparently it was some other kind of child handle
-    *pResultDevice = Unknown;
-    ReturnCode = EFI_UNSUPPORTED;
+    // The child handle is not our DIMM... but it can be our namespace
+    if (HandleToNamespace(ChildHandle) != NULL) {
+      *pResultDevice = Namespace;
+      ReturnCode = EFI_SUCCESS;
+    }
+    else {
+      *pResultDevice = Unknown;
+      ReturnCode = EFI_UNSUPPORTED;
+    }
+    goto Finish;
   }
 
   if (pDimmPid != NULL) {
     *pDimmPid = DimmPid;
   }
+
 Finish:
 #endif
   NVDIMM_EXIT_I64(ReturnCode);
