@@ -7,7 +7,9 @@
 * @file NvmDimmConfig.h
 * @brief Implementation of the EFI_DCPMM_CONFIG2_PROTOCOL, a custom protocol
 * to configure and manage PMem modules
-*
+**/
+
+/**
 * @mainpage Intel Optane Persistent Memory Software UEFI FW Protocols
 *
 * @section Introduction
@@ -523,7 +525,7 @@ RecoverDimmFw(
   @param[in] Examine flag enables image verification only
   @param[in] Force flag suppresses warning message in case of attempted downgrade
   @param[in] Recovery flag determine that recovery update should be performed
-  @param[in] FlashSPI flag determine if the recovery update should be through the SPI
+  @param[in] Reserved Set to FALSE
 
   @param[out] pFwImageInfo is a pointer to a structure containing FW image information
     need to be provided if examine flag is set
@@ -549,7 +551,7 @@ UpdateFw(
   IN     BOOLEAN Examine,
   IN     BOOLEAN Force,
   IN     BOOLEAN Recovery,
-  IN     BOOLEAN FlashSPI,
+  IN     BOOLEAN Reserved,
      OUT NVM_FW_IMAGE_INFO *pFwImageInfo OPTIONAL,
      OUT COMMAND_STATUS *pCommandStatus
 );
@@ -1256,7 +1258,7 @@ GetDcpmmCapacities(
 /**
   Retrieve and calculate DDR cache and memory capacity to return.
 
-  @param[in]  SocketId Socket Id for SKU limit calculations, value 0xFFFF indicate include all sockets values accumulated
+  @param[in]  SocketId Socket Id, value 0xFFFF indicates include all socket values
   @param[out] pDDRRawCapacity Pointer to value of the total cache capacity
   @param[out] pDDRCacheCapacity Pointer to value of the DDR cache capacity
   @param[out] pDDRVolatileCapacity Pointer to value of the DDR memory capacity
@@ -1278,10 +1280,10 @@ GetDDRCapacities(
 
 /**
   Calculate the total size of available memory in the PMem modules
-  according to the smbios and return the result.
+  according to the smbios and return the result
 
-  @param[in]  SocketId Socket Id for SKU limit calculations, value 0xFFFF indicate include all sockets values accumulated.
-  @param[out] pResult Pointer to total memory size.
+  @param[in]  SocketId Socket Id, value 0xFFFF indicates include all socket values
+  @param[out] pResult Pointer to total memory size
 
   @retval EFI_INVALID_PARAMETER Passed NULL argument
   @retval EFI_LOAD_ERROR Failure to calculate DDR memory size
