@@ -72,6 +72,8 @@ typedef enum {
   MEMORY_MODE_2LM = 1
 } MEMORY_MODE;
 
+typedef SUPPORTED_MEMORY_MODE3 MEMORY_MODE_CAPABILITIES;
+
 /**
   ACPI Related Functions
 **/
@@ -80,39 +82,51 @@ typedef enum {
   ParseNfitTable - Performs deserialization from binary memory block into parsed structure of pointers.
 
   @param[in] pTable pointer to the memory containing the NFIT binary representation.
+  @param[out] ppParsedNfit Pointer to a pointer where the allocated and parsed NFIT table will be stored
 
-  @retval NULL if there was an error while parsing the memory.
-  @retval pointer to the allocated header with parsed NFIT.
+  @retval EFI_INVALID_PARAMETER One of the provided parameters is invalid
+  @retval EFI_VOLUME_CORRUPTED If the table checksum is invalid
+  @retval EFI_INCOMPATIBLE_VERSION If the table is not compatible with this ipmctl version
+  @retval EFI_SUCCESS
 **/
-ParsedFitHeader *
+EFI_STATUS
 ParseNfitTable(
-  IN     VOID *pTable
+  IN     VOID *pTable,
+     OUT ParsedFitHeader **ppParsedNfit
   );
 
 /**
   Performs deserialization from binary memory block, containing PCAT tables, into parsed structure of pointers.
 
   @param[in] pTable pointer to the memory containing the PCAT binary representation.
+  @param[out] ppParsedPcat Pointer to a pointer where the allocated and parsed PCAT table will be stored
 
-  @retval NULL if there was an error while parsing the memory.
-  @retval pointer to the allocated header with parsed PCAT.
+  @retval EFI_INVALID_PARAMETER One of the provided parameters is invalid
+  @retval EFI_VOLUME_CORRUPTED If the table checksum is invalid
+  @retval EFI_INCOMPATIBLE_VERSION If the table is not compatible with this ipmctl version
+  @retval EFI_SUCCESS
 **/
-ParsedPcatHeader *
+EFI_STATUS
 ParsePcatTable (
-  IN     VOID *pTable
+  IN     VOID *pTable,
+     OUT ParsedPcatHeader **ppParsedPcat
   );
 
 /**
   Performs deserialization from binary memory block, containing PMTT tables, into parsed structure of pointers.
 
   @param[in] pTable pointer to the memory containing the PMTT binary representation.
+  @param[out] ppParsedPmtt Pointer to a pointer where the allocated and parsed PMTT table will be stored
 
-  @retval NULL if there was an error while parsing the memory.
-  @retval pointer to the allocated header with parsed PMTT.
+  @retval EFI_INVALID_PARAMETER One of the provided parameters is invalid
+  @retval EFI_VOLUME_CORRUPTED If the table checksum is invalid
+  @retval EFI_INCOMPATIBLE_VERSION If the table is not compatible with this ipmctl version
+  @retval EFI_SUCCESS
 **/
-ParsedPmttHeader *
+EFI_STATUS
 ParsePmttTable(
-  IN     VOID *pTable
+  IN     VOID *pTable,
+     OUT ParsedPmttHeader **ppParsedPmtt
   );
 
 /**
@@ -359,7 +373,6 @@ AllowedMemoryMode(
   @retval EFI_SUCCESS Success
   @retval EFI_INVALID_PARAMETER Input parameter is NULL
   @retval EFI_LOAD_ERROR PCAT tables not found
-  @retval EFI_UNSUPPORTED Config change request through management software not supported
 **/
 EFI_STATUS
 CheckIfBiosSupportsConfigChange(
@@ -369,20 +382,15 @@ CheckIfBiosSupportsConfigChange(
 /**
   Check Memory Mode Capabilties from PCAT table type 0
 
-  @param[in] pMemMode2LMSupported 2LM Mode Support
-  @param[in] pAppDirectPMSupported AppDirect PM Mode Support
-  @param[in] pMemMode1LMSupported 2LM Memory Mode Support
+  @param[out] pMemoryModeCapabilities pointer to memory mode capabilites
 
   @retval EFI_SUCCESS Success
   @retval EFI_INVALID_PARAMETER Input parameter is NULL
   @retval EFI_LOAD_ERROR PCAT tables not found
-  @retval EFI_UNSUPPORTED Config change request through management software not supported
 **/
 EFI_STATUS
 CheckMemModeCapabilities(
-  OUT BOOLEAN *pMemMode2LMSupported,
-  OUT BOOLEAN *pAppDirectPMSupported,
-  OUT BOOLEAN *pMemMode1LMSupported
+  OUT MEMORY_MODE_CAPABILITIES *pMemoryModeCapabilities
   );
 
 /**
