@@ -99,6 +99,18 @@ enum
 */
 static struct debug_logger_config g_log_config = { 0 };
 
+static EFI_STATUS ConvertAsciiStrToUnicode(const CHAR8 * AsciiStr, CHAR16 * UnicodeStr, UINTN UnicodeStrMaxLength) {
+  EFI_STATUS ReturnCode;
+  if ((NULL == AsciiStr) || (NULL == UnicodeStr)) {
+    return EFI_INVALID_PARAMETER;
+  }
+  ReturnCode = AsciiStrToUnicodeStrS(AsciiStr, UnicodeStr, UnicodeStrMaxLength);
+  if (ReturnCode != EFI_SUCCESS) {
+    Print(L"Failed to convert Ascii string to Unicode string. Return code = %d.\n", ReturnCode);
+  }
+  return ReturnCode;
+}
+
 EFI_STATUS
 EFIAPI
 DefaultPassThru(
@@ -240,7 +252,6 @@ initAcpiTables()
   if (EFI_ERROR(ReturnCode))
   {
     NVDIMM_WARN("Failed to parse NFIT or PCAT or PMTT table.");
-    ReturnCode = EFI_NOT_FOUND;
     goto Finish;
   }
 
@@ -446,6 +457,7 @@ void (*rel_assert) (void) = NULL;
 */
 static void write_system_event_to_stdout(const char* source, const char* message)
 {
+  RETURN_STATUS ReturnCode = EFI_SUCCESS;
   NVM_EVENT_MSG ascii_event_message = { 0 };
   CHAR16 w_event_message[sizeof(ascii_event_message)] = { 0 };
 
@@ -454,11 +466,15 @@ static void write_system_event_to_stdout(const char* source, const char* message
   os_strcat(ascii_event_message, sizeof(ascii_event_message), " ");
   os_strcat(ascii_event_message, sizeof(ascii_event_message), message);
   os_strcat(ascii_event_message, sizeof(ascii_event_message), "\n");
-  // Convert to the unicode
-  AsciiStrToUnicodeStr(ascii_event_message, w_event_message);
+
+  // Convert to the unicode  --  length of array is sizeof(ascii_event_message)
+  CHECK_RESULT(ConvertAsciiStrToUnicode(ascii_event_message, w_event_message, sizeof(ascii_event_message)), Finish);
 
   // Send it to standard output
   Print(FORMAT_STR, w_event_message);
+
+Finish:
+  return;
 }
 
 /**
@@ -1136,6 +1152,7 @@ StrnCatGrow(
 {
   UINTN DestinationStartSize;
   UINTN NewSize;
+  UINTN DestMaxSize;
 
   //
   // ASSERTs
@@ -1188,9 +1205,11 @@ StrnCatGrow(
       *Destination = ReallocatePool(*CurrentSize, NewSize, *Destination);
       *CurrentSize = NewSize;
     }
+    DestMaxSize = *CurrentSize;
   }
   else {
-    *Destination = AllocateZeroPool((Count + 1) * sizeof(CHAR16));
+    DestMaxSize = ((Count + 1) * sizeof(CHAR16));
+    *Destination = AllocateZeroPool(DestMaxSize);
   }
 
   //
@@ -1199,7 +1218,9 @@ StrnCatGrow(
   if (*Destination == NULL) {
     return (NULL);
   }
-  return StrnCat(*Destination, Source, Count);
+  // divide by the size of CHAR16 to convert max number of bytes to max number CHAR16s
+  StrnCatS(*Destination, (DestMaxSize/sizeof(CHAR16)), Source, Count);
+  return *Destination;
 }
 
 /**
@@ -1614,6 +1635,7 @@ PromptedInput(
   EFI_STATUS ReturnCode = EFI_SUCCESS;
   int PromptIndex;
   char ThrowAway;
+  VOID * ptr;
   BOOLEAN NoReturn = TRUE;
 
   NVDIMM_ENTRY();
@@ -1649,13 +1671,16 @@ PromptedInput(
     }
   }
 
-  VOID * ptr = AllocateZeroPool((PromptIndex * (sizeof(CHAR16))));
+  ptr = AllocateZeroPool(PromptIndex * (sizeof(CHAR16)));
   if (NULL == ptr) {
     ReturnCode = EFI_OUT_OF_RESOURCES;
     goto Finish;
   }
 
-  *ppReturnValue = AsciiStrToUnicodeStr(buff, ptr);
+  ReturnCode = ConvertAsciiStrToUnicode(buff, ptr, PromptIndex);
+  if (!EFI_ERROR(ReturnCode)) {
+    *ppReturnValue = ptr;
+  }
 
 Finish:
   Print(L"\n");
@@ -1892,7 +1917,7 @@ GetVendorDriverVersion(CHAR16 * pVersion, UINTN VersionStrSize)
 
   if (0 == get_vendor_driver_revision(ascii_buffer, sizeof(ascii_buffer)))
   {
-    AsciiStrToUnicodeStr(ascii_buffer, pVersion);
+    ConvertAsciiStrToUnicode(ascii_buffer, pVersion, VersionStrSize);
   }
   else
   {
