@@ -7,6 +7,7 @@
 #include <UefiBaseType.h>
 #include <BaseLib.h>
 #include <ini.h>
+#include <Debug.h>
 
 #if defined(__LINUX__) || defined(__ESX__)
 #define INI_FILENAME		"ipmctl.conf"
@@ -52,32 +53,32 @@ EFI_STATUS preferences_flush_the_file(void)
 }
 
 EFI_STATUS preferences_get_var_ascii(IN CONST char    *name,
-	IN CONST EFI_GUID  guid,
-	OUT VOID           *value,
-	OUT UINTN          *size OPTIONAL)
+  IN CONST EFI_GUID  guid,
+  OUT VOID           *value,
+  OUT UINTN          *size OPTIONAL)
 {
-	int val = nvm_ini_get_int_value(gIni, name, -1);
-	if (-1 == val)
-	{
-		return EFI_NOT_FOUND;
-	}
-	if (1 == *size)
-	{
-		*(unsigned char*)value = (unsigned char)val;
-	}
-	else if (2 == *size)
-	{
-		*(unsigned short*)value = (unsigned short)val;
-	}
-	else if (4 == *size)
-	{
-		*(unsigned int*)value = (unsigned int)val;
-	}
-	else
-	{
-		return EFI_NOT_FOUND;
-	}
-	return EFI_SUCCESS;
+  int val = nvm_ini_get_int_value(gIni, name, -1);
+  if (-1 == val)
+  {
+    return EFI_NOT_FOUND;
+  }
+  if (1 == *size)
+  {
+    *(unsigned char*)value = (unsigned char)val;
+  }
+  else if (2 == *size)
+  {
+    *(unsigned short*)value = (unsigned short)val;
+  }
+  else if (4 == *size)
+  {
+    *(unsigned int*)value = (unsigned int)val;
+  }
+  else
+  {
+    return EFI_NOT_FOUND;
+  }
+  return EFI_SUCCESS;
 }
 
 EFI_STATUS preferences_get_string_ascii(IN CONST char    *name,
@@ -97,9 +98,7 @@ EFI_STATUS preferences_get_string_ascii(IN CONST char    *name,
         return EFI_BUFFER_TOO_SMALL;
     }
 
-    AsciiStrCpy(value, ret_string);
-
-    return EFI_SUCCESS;
+    return AsciiStrCpyS(value, size, ret_string);
 }
 
 EFI_STATUS preferences_get_var(IN CONST CHAR16    *name,
@@ -107,88 +106,113 @@ EFI_STATUS preferences_get_var(IN CONST CHAR16    *name,
   OUT VOID           *value,
   OUT UINTN          *size OPTIONAL)
 {
-	char tmp[256];
-	UnicodeStrToAsciiStr(name, tmp);
-	return preferences_get_var_ascii(tmp, guid, value, size);
+  char tmp[256];
+  UnicodeStrToAsciiStrS(name, tmp, sizeof(tmp));
+  return preferences_get_var_ascii(tmp, guid, value, size);
 }
 
 EFI_STATUS preferences_get_var_string_wide(IN CONST CHAR16    *name,
   IN CONST EFI_GUID  guid,
   OUT CHAR16         *value,
-  OUT UINTN          *size OPTIONAL)
+  IN UINTN          *size )
 {
-	char key[256];
-	const char * ascii_str;
+  char key[256];
+  const char * ascii_str;
+  EFI_STATUS ReturnCode;
+
+  if ((NULL == value) || (NULL == size))
+  {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  CHECK_RESULT( UnicodeStrToAsciiStrS(name, key, sizeof(key)), Finish);
 
-	UnicodeStrToAsciiStr(name, key);
   if (NULL == (ascii_str = nvm_ini_get_string(gIni, (const char *)key)))
   {
-    return EFI_NOT_FOUND;
+    ReturnCode = EFI_NOT_FOUND;
+    goto Finish;
   }
-	AsciiStrToUnicodeStr(ascii_str, value);
-	return EFI_SUCCESS;
+
+  CHECK_RESULT(AsciiStrToUnicodeStrS(ascii_str, value, *size), Finish);
+
+  ReturnCode = EFI_SUCCESS;
+
+Finish:
+  return ReturnCode;
 }
 
 EFI_STATUS preferences_set_var(IN CONST CHAR16 *name,
-	IN CONST EFI_GUID guid, OUT VOID *value, OUT UINTN size)
+  IN CONST EFI_GUID guid, OUT VOID *value, OUT UINTN size)
 {
-	char key[256];
-	char val[256];
+  char key[256];
+  char val[256];
+  EFI_STATUS ReturnCode;
 
-	UnicodeStrToAsciiStr(name, key);
+  CHECK_RESULT(UnicodeStrToAsciiStrS(name, key, sizeof(key)), Finish);
 
-	if (1 == size)
-	{
-		snprintf(val, sizeof(val), "%d", *(unsigned char*)value);
-	}
-	else if (2 == size)
-	{
-		snprintf(val, sizeof(val), "%d", *(unsigned short*)value);
-	}
-	else if (4 == size)
-	{
-		snprintf(val, sizeof(val), "%d", *(unsigned int*)value);
-	}
-	else
-	{
-		return EFI_NOT_FOUND;
-	}
+  if (1 == size)
+  {
+    snprintf(val, sizeof(val), "%d", *(unsigned char*)value);
+  }
+  else if (2 == size)
+  {
+    snprintf(val, sizeof(val), "%d", *(unsigned short*)value);
+  }
+  else if (4 == size)
+  {
+    snprintf(val, sizeof(val), "%d", *(unsigned int*)value);
+  }
+  else
+  {
+    ReturnCode = EFI_NOT_FOUND;
+    goto Finish;
+  }
 
-	int ret = nvm_ini_set_value(gIni, key, val);
-	if(0 != ret)
-	{
-		return EFI_LOAD_ERROR;
-	}
+  int ret = nvm_ini_set_value(gIni, key, val);
+  if(0 != ret)
+  {
+    ReturnCode = EFI_LOAD_ERROR;
+    goto Finish;
+  }
 
-	return EFI_SUCCESS;
+  ReturnCode = EFI_SUCCESS;
+
+Finish:
+  return ReturnCode;
 }
 
 EFI_STATUS preferences_set_var_string_wide(IN CONST CHAR16 *name,
-	IN CONST EFI_GUID guid, IN CHAR16 *value)
+  IN CONST EFI_GUID guid, IN CHAR16 *value)
 {
-	char key[256];
-	char val[256];
+  char key[256];
+  char val[256];
+  EFI_STATUS ReturnCode;
 
-	UnicodeStrToAsciiStr(name, key);
-	UnicodeStrToAsciiStr(value, val);
+  CHECK_RESULT(UnicodeStrToAsciiStrS(name, key, sizeof(key)), Finish);
+
+  CHECK_RESULT(UnicodeStrToAsciiStrS(value, val, sizeof(val)), Finish);
 
   int ret = nvm_ini_set_value(gIni, key, val);
-	if (0 != ret)
-	{
-		return EFI_LOAD_ERROR;
-	}
+  if (0 != ret)
+  {
+    ReturnCode = EFI_LOAD_ERROR;
+    goto Finish;
+  }
 
-	return EFI_SUCCESS;
+  return EFI_SUCCESS;
+
+Finish:
+  return ReturnCode;
 }
 
 EFI_STATUS preferences_set_var_string_ascii(IN CONST char *name,
-	IN CONST EFI_GUID guid, IN const char *value)
+  IN CONST EFI_GUID guid, IN const char *value)
 {
-	int ret = nvm_ini_set_value(gIni, name, value);
-	if (0 != ret)
-	{
-		return EFI_LOAD_ERROR;
-	}
+  int ret = nvm_ini_set_value(gIni, name, value);
+  if (0 != ret)
+  {
+    return EFI_LOAD_ERROR;
+  }
 
   return EFI_SUCCESS;
 }
